"use strict";
/*
 * Copyright (c) 2021, salesforce.com, inc.
 * All rights reserved.
 * Licensed under the BSD 3-Clause license.
 * For full license text, see LICENSE.txt file in the repo root or https://opensource.org/licenses/BSD-3-Clause
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.DeployProgress = exports.ProgressBar = void 0;
const util = require("util");
const cli_ux_1 = require("cli-ux");
const kit_1 = require("@salesforce/kit");
const startProgressBar = kit_1.once((bar, total) => {
    bar.start(total);
});
class ProgressBar {
    constructor(options = ProgressBar.DEFAULT_OPTIONS) {
        const opts = Object.assign(ProgressBar.DEFAULT_OPTIONS, options);
        opts.format = util.format(opts.format, opts.title);
        this.bar = cli_ux_1.default.progress({
            format: opts.format,
            barCompleteChar: opts.barCompleteChar,
            barIncompleteChar: opts.barIncompleteChar,
            linewrap: opts.linewrap,
        });
    }
    setTotal(total) {
        this.total = total;
        this.bar.setTotal(total);
    }
    start(total) {
        this.total = total;
        startProgressBar(this.bar, total);
    }
    update(num) {
        this.bar.update(num);
    }
    finish() {
        this.bar.update(this.total);
        this.bar.stop();
    }
    stop() {
        this.bar.stop();
    }
}
exports.ProgressBar = ProgressBar;
ProgressBar.DEFAULT_OPTIONS = {
    title: 'SOURCE PROGRESS',
    format: '%s | {bar} | {value}/{total} Components',
    barCompleteChar: '\u2588',
    barIncompleteChar: '\u2591',
    linewrap: true,
};
class DeployProgress extends ProgressBar {
    constructor(deploy) {
        super();
        this.deploy = deploy;
    }
    start() {
        if (!kit_1.env.getBoolean('SF_USE_PROGRESS_BAR', true))
            return;
        this.deploy.onUpdate((data) => {
            // the numCompTot. isn't computed right away, wait to start until we know how many we have
            if (data.numberComponentsTotal) {
                super.start(data.numberComponentsTotal + data.numberTestsTotal);
                this.update(data.numberComponentsDeployed + data.numberTestsCompleted);
            }
            // the numTestsTot. isn't computed until validated as tests by the server, update the PB once we know
            if (data.numberTestsTotal && data.numberComponentsTotal) {
                this.setTotal(data.numberComponentsTotal + data.numberTestsTotal);
            }
        });
        // any thing else should stop the progress bar
        this.deploy.onFinish(() => this.finish());
        this.deploy.onCancel(() => this.stop());
        this.deploy.onError((error) => {
            this.stop();
            throw error;
        });
    }
}
exports.DeployProgress = DeployProgress;
//# sourceMappingURL=progressBar.js.map